@@ -42,9 +42,6 @@ pub use captures::{Capture, Captures};
 mod r#match;
 pub use r#match::Match;
 
-mod route;
-pub use route::{Route, RouteSpec};
-
 mod router;
 pub use router::Router;
 
@@ -53,3 +50,6 @@ pub use segment::Segment;
 
 mod reverse_match;
 pub use reverse_match::ReverseMatch;
+
+mod route_spec;
+pub use route_spec::RouteSpec;
